@@ -316,14 +316,12 @@ get_pid(const char *pidfile, bool quiet)
 		return -1;
 
 	if ((fp = fopen(pidfile, "r")) == NULL) {
-		if (!quiet)
-			eerror("%s: fopen `%s': %s", applet, pidfile, strerror(errno));
+		ewarnv("%s: fopen `%s': %s", applet, pidfile, strerror(errno));
 		return -1;
 	}
 
 	if (fscanf(fp, "%d", &pid) != 1) {
-		if (!quiet)
-			eerror("%s: no pid found in `%s'", applet, pidfile);
+		ewarnv("%s: no pid found in `%s'", applet, pidfile);
 		fclose(fp);
 		return -1;
 	}
@@ -461,7 +459,7 @@ run_stop_schedule(const char *exec, const char *const *argv,
 				{
 					if ((nrunning = do_stop(exec, argv,
 						    pid, uid, 0, true, false,
-						    true)) == 0)
+	test)) == 0)
 						return 0;
 
 
@@ -1088,7 +1086,7 @@ start_stop_daemon(int argc, char **argv)
 		pid = 0;
 
 	if (do_stop(exec, (const char * const *)margv, pid, uid,
-		0, true, false, true) > 0)
+		0, true, false, test) > 0)
 		eerrorx("%s: %s is already running", applet, exec);
 
 	if (test) {
@@ -1366,7 +1364,7 @@ start_stop_daemon(int argc, char **argv)
 			} else
 				pid = 0;
 			if (do_stop(exec, (const char *const *)margv,
-				pid, uid, 0, true, false, true) > 0)
+				pid, uid, 0, true, false, test) > 0)
 				alive = true;
 		}
 
